@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Test::JSON::Schema::Acceptance; # git description: v1.013-11-gc922512
+package Test::JSON::Schema::Acceptance; # git description: v1.015-5-g58b267c
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Acceptance testing for JSON-Schema based validators like JSON::Schema
 
-our $VERSION = '1.014';
+our $VERSION = '1.016';
 
 use 5.020;
 use Moo;
@@ -135,7 +135,7 @@ sub acceptance {
     $self->additional_resources->visit(
       sub ($path, @) {
         return if not $path->is_file or $path !~ /\.json$/;
-        my $data = $self->_json_decoder->decode($path->slurp_raw);
+        my $data = $self->json_decoder->decode($path->slurp_raw);
         my $file = $path->relative($self->additional_resources);
         my $uri = $base.'/'.$file;
         $options->{add_resource}->($uri => $data);
@@ -187,10 +187,10 @@ sub acceptance {
         my $result = $options->{validate_data}
           ? $options->{validate_data}->($metaspec_uri, $test_group->{schema})
           # we use the decoder here so we don't prettify the string
-          : $options->{validate_json_string}->($metaspec_uri, $self->_json_decoder->encode($test_group->{schema}));
+          : $options->{validate_json_string}->($metaspec_uri, $self->json_decoder->encode($test_group->{schema}));
         if (not $result) {
           $ctx->fail('schema for '.$one_file->{file}.': "'.$test_group->{description}.'" fails to validate against '.$metaspec_uri.':');
-          $ctx->note($self->_json_encoder->encode($result));
+          $ctx->note($self->json_encoder->encode($result));
           $schema_fails = 1;
         }
       }
@@ -258,15 +258,16 @@ sub _run_test ($self, $one_file, $test_group, $test, $options) {
     sub {
       my ($result, $schema_before, $data_before, $schema_after, $data_after);
       try {
-        ($schema_before, $data_before) = map $self->_json_decoder->encode($_),
+        # we use the decoder here so we don't prettify the string
+        ($schema_before, $data_before) = map $self->json_decoder->encode($_),
           $test_group->{schema}, $test->{data};
 
         $result = $options->{validate_data}
           ? $options->{validate_data}->($test_group->{schema}, $test->{data})
             # we use the decoder here so we don't prettify the string
-          : $options->{validate_json_string}->($test_group->{schema}, $self->_json_decoder->encode($test->{data}));
+          : $options->{validate_json_string}->($test_group->{schema}, $self->json_decoder->encode($test->{data}));
 
-        ($schema_after, $data_after) = map $self->_json_decoder->encode($_),
+        ($schema_after, $data_after) = map $self->json_decoder->encode($_),
           $test_group->{schema}, $test->{data};
 
         my $ctx = Test2::API::context;
@@ -286,29 +287,33 @@ sub _run_test ($self, $one_file, $test_group, $test, $options) {
         my @mutated_data_paths = $self->_mutation_check($test->{data});
         my @mutated_schema_paths = $self->_mutation_check($test_group->{schema});
 
-        if ($data_before ne $data_after or @mutated_data_paths) {
-          if ($data_before ne $data_after) {
-            Test2::Tools::Compare::is($data_after, $data_before, 'evaluator did not mutate data');
-          }
-          else {
-            $ctx->fail('evaluator did not mutate data');
-          }
+        # string check   path check    behaviour
+        #            0            0    ::is(), and note. $pass = 0
+        #            0            1    ::is().           $pass = 0
+        #            1            0    ->fail and note.  $pass = 0
+        #            1            1    no test. $pass does not change.
 
-          $ctx->note('mutated data at location'.(@mutated_data_paths > 1 ? 's' : '').': '.join(', ', @mutated_data_paths)) if @mutated_data_paths;
+        if ($data_before ne $data_after) {
+          Test2::Tools::Compare::is($data_after, $data_before, 'evaluator did not mutate data');
+          $pass = 0;
+        }
+        elsif (@mutated_data_paths) {
+          $ctx->fail('evaluator did not mutate data');
+          $pass = 0
+        }
+
+        $ctx->note('mutated data at location'.(@mutated_data_paths > 1 ? 's' : '').': '.join(', ', @mutated_data_paths)) if @mutated_data_paths;
+
+        if ($schema_before ne $schema_after) {
+          Test2::Tools::Compare::is($schema_after, $schema_before, 'evaluator did not mutate schema');
+          $pass = 0;
+        }
+        elsif (@mutated_schema_paths) {
+          $ctx->fail('evaluator did not mutate schema');
           $pass = 0;
         }
 
-        if ($schema_before ne $schema_after or @mutated_schema_paths) {
-          if ($schema_before ne $schema_after) {
-            Test2::Tools::Compare::is($schema_after, $schema_before, 'evaluator did not mutate schema');
-          }
-          else {
-            $ctx->fail('evaluator did not mutate schema');
-          }
-
-          $ctx->note('mutated schema at location'.(@mutated_schema_paths > 1 ? 's' : '').': '.join(', ', @mutated_schema_paths)) if @mutated_schema_paths;
-          $pass = 0;
-        }
+        $ctx->note('mutated schema at location'.(@mutated_schema_paths > 1 ? 's' : '').': '.join(', ', @mutated_schema_paths)) if @mutated_schema_paths;
 
         $ctx->release;
       }
@@ -356,25 +361,29 @@ sub _mutation_check ($self, $data) {
 }
 
 # used for internal serialization also
-has _json_decoder => (
+has json_decoder => (
   is => 'ro',
   isa => HasMethods[qw(encode decode)],
   lazy => 1,
-  default => sub { JSON::MaybeXS->new(allow_nonref => 1, utf8 => 1, allow_bignum => 1, allow_blessed => 1) },
+  default => sub { JSON::MaybeXS->new(allow_nonref => 1, utf8 => 1, allow_blessed => 1) },
 );
 
 # used for pretty-printing diagnostics
-has _json_encoder => (
+has json_encoder => (
   is => 'ro',
   isa => HasMethods['encode'],
   lazy => 1,
   default => sub {
-    my $encoder = shift->_json_decoder->convert_blessed->canonical->pretty;
+    my $encoder = shift->json_decoder->convert_blessed->canonical->pretty;
     $encoder->indent_length(2) if $encoder->can('indent_length');
     $encoder;
   },
 );
 
+# backcompat shims
+sub _json_decoder { shift->json_decoder(@_) }
+sub _json_encoder { shift->json_encoder(@_) }
+
 # see JSON::MaybeXS::is_bool
 my $json_bool = InstanceOf[qw(JSON::XS::Boolean Cpanel::JSON::XS::Boolean JSON::PP::Boolean)];
 
@@ -407,7 +416,7 @@ sub _build__test_data ($self) {
       return if any { $self->test_dir->child($_)->subsumes($path) } $self->skip_dir->@*;
       return if not $path->is_file;
       return if $path !~ /\.json$/;
-      my $data = $self->_json_decoder->decode($path->slurp_raw);
+      my $data = $self->json_decoder->decode($path->slurp_raw);
       return if not @$data; # placeholder files for renamed tests
       my $file = $path->relative($self->test_dir);
       push @test_groups, [
@@ -490,7 +499,7 @@ Test::JSON::Schema::Acceptance - Acceptance testing for JSON-Schema based valida
 
 =head1 VERSION
 
-version 1.014
+version 1.016
 
 =head1 SYNOPSIS
 
@@ -782,10 +791,15 @@ Ricardo Signes <rjbs@cpan.org> for direction to and creation of Test::Fatal.
 
 Various others in #perl-help.
 
+=for stopwords OpenAPI
+
 =head1 SUPPORT
 
 Bugs may be submitted through L<https://github.com/karenetheridge/Test-JSON-Schema-Acceptance/issues>.
 
+You can also find me on the L<JSON Schema Slack server|https://json-schema.slack.com> and L<OpenAPI Slack
+server|https://open-api.slack.com>, which are also great resources for finding help.
+
 =head1 AUTHOR
 
 Ben Hutton (@relequestual) <relequest@cpan.org>
